@@ -38,9 +38,9 @@ install_requires = [
     # -*- Install requires: -*-
     'setuptools',
     'ipython>=0.12',
-    'apptools>=4.0.1.dev',
-    'traitsui>=4.1.1.dev',
-    'mayavi>=4.1.1.dev',
+    'apptools>=4.1.0',
+    'traitsui>=4.2.0',
+    'mayavi>=4.2.0',
     ]
 
 entry_points="""
@@ -97,7 +97,15 @@ if ALL_TASKS_LOADED:
 
 
 @task
-@needs(['docs', 'ghpages'])
+def create_CNAME():
+    "creates the CNAME for the domain when deployed"
+    filename = os.path.join('docs', '_build', 'html', "CNAME")
+    if not os.path.exists(filename): 
+        with open(filename, 'w') as f:
+            f.write("neuronvisio.org")
+
+@task
+@needs(['docs', 'create_CNAME', 'ghpages'])
 def update_docs():
     """Generate the website and updates pages on github
     """
